---
title: 状态码
sidebar_position: 210
---

import Accordion from '/src/components/Accordion/index.jsx'
import codeString from '!!raw-loader!./code.yaml';

## HTTP 状态码

| 状态码 | 描述             | 详细解释 |
| :-----|:-----------------|:--------------------------------------------- |
| 200  | 成功             | 成功 |
| 400  | 请求参数错误         | 该请求是无效的，详细的错误信息会说明原因 |
| 401  | 未授权           | 验证失败，详细的错误信息会说明原因 |
| 403  | 服务器拒绝请求    | 被拒绝调用，详细的错误信息会说明原因 |
| 404  | 未找到          | 服务器找不到请求的地址 |
| 405  | 请求方法不支持          | 群容量超出上限，禁止请求此方法 |
| 429  | 请求频率超限        | 超出了调用频率限制，详细的错误信息会说明原因 |
| 430  | 未开通服务        | 一般为未开通服务导致，详细的错误信息会说明原因 |
| 500  | 服务器内部错误      | 服务器内部出错了，请联系我们尽快解决问题 |
| 504  | 网关超时          | 服务器在运行，本次请求响应超时，请稍后重试 |

## 业务返回码

<Accordion contents={ codeString } />

| 状态码  | 描述             | 详细解释   |
| :-----|:-----------------|:---------------------------------------|
|  404  | 未找到           | 服务器找不到请求的地址（HTTP 状态码  404） |
|  1000 | 服务内部错误     | 服务器端内部逻辑错误,请稍后重试（HTTP 状态码  500） |
|  1001 | App Secret 错误  | App Key 与 App Secret 不匹配（HTTP 状态码  401） |
|  1002 | 参数错误         | 参数错误，详细的描述信息会说明（HTTP 状态码  400） |
|  1003 | 无 POST 数据     | 没有 POST 任何数据（HTTP 状态码  400） |
|  1004 | 验证签名错误     | 验证签名错误（HTTP 状态码  401） |
|  1005 | 参数长度超限     | 参数长度超限，详细的描述信息会说明（HTTP 状态码  400） |
|  1006 | App 被锁定或删除 | App 被锁定或删除（HTTP 状态码  401） |
|  1007 | 被限制调用       | 该方法被限制调用，详细的描述信息会说明（HTTP 状态码  401） |
|  1008 | 调用频率超限     | 调用频率超限。注意，即使未开通 API 相关服务，如果连续请求导致 API 调用频率超限，也会触发该错误。（HTTP 状态码  429） |
|  1009 | 服务未开通      | 未开通该服务，请到开发者管理后台开通或提交工单申请。（HTTP 状态码  430） |
|  1010 | 服务未开通      | 未开通白名单服务，请到开发者管理后台开通或提交工单申请。（HTTP 状态码  430） |
|  1011 | 服务未开通      | 未开通黑名单服务，请到开发者管理后台开通或提交工单申请。（HTTP 状态码  430） |
|  1015 | 删除的数据不存在  | 要删除的保活聊天室 ID 不存在。（HTTP 状态码  200） |
|  1016 | 设置保活聊天室个数超限 | 设置的保活聊天室个数超限。（HTTP 状态码  403） |
|  1017 | 实时音视频 SDK 版本不支持  | 音视频 SDK 版本不支持，请使用 2.9.0 及之后的实时音视频 SDK。|HTTP 状态码 403 |
|  1018 | 实时音视频服务未开启 | 未开启服务，请到开发者管理后台开通实时音视频服务。（HTTP 状态码  403） |
|  1050 | 内部服务超时     | 内部服务响应超时（HTTP 状态码  504） |
|  2007 | 注册用户数量超限 | 开发环境下注册用户上限为 100 个，生产环境未开通 IM 付费版本时可免费注册 100个，超过后需要升级到付费版本，私有部署客户请联系商务；单独使用音视频服务没有注册用户数限制，如您单独使用音视频服务触发了该错误，请检查您的音视频服务是否因欠费或其它原因处于关停状态。                 | HTTP 状态码403 |
| 20107 | 单聊黑名单人数超限 | 调用「添加用户到黑名单」接口，用户 ID 的黑名单人数已达到上限（3000 ），返回该错误码。 |
| 20108 | 单聊白名单人数超限  | 调用「添加用户到白名单」接口，用户 ID 的白名单人数已达到上限（3000 ），返回该错误码。 |
| 23407 | 聊天室禁言白名单人数超限  | 单次 API 请求中聊天室中禁言白名单用户已达到上限（20 个），返回该错误码。请分次添加禁言白名单用户。 |
| 23423 | 聊天室属性超限  | 单个聊天室最多设置 100 个属性 KV。如果超过个数上限，当前请求设置的属性全部设置失败，返回该错误码和当前已有的属性数量。 |
| 23426 | 聊天室属性功能未开通  | 聊天室自定义属性未开通时，返回该错误码。 |
| 23410 | 聊天室不存在  | 聊天室不存在。 |
| 23432 | 聊天室销毁时间不合法  | 设置聊天室销毁时间（分钟）非有效值时，返回该错误码。有效值为 [60 - 10080] 的整数。 |
| 23433 | 聊天室销毁类型不合法  | 设置聊天室销毁类型非有效值时，返回该错误码。有效值请参见文档中定义的类型对应值。 |
| 23434 | 聊天室属性无对应用户 ID  | 如果设置聊天室自定义属性，必须同时传用户 ID，否则返回该错误码。 |
| 23435 | 聊天室已存在  | 创建聊天室时聊天室已存在，返回该错误码。 |
| 23436 | 聊天室存活时长无效  | 为定时销毁的聊天室设置存活时长时，应保证传入的存活时长大于聊天室自创建后的已存活时长，否则返回该错误码。 |
| 24353 | 重复注销 | 调用注销接口，传入已完成注销的用户 ID 时，返回该错误码。 |
| 24354 | 重复激活 | 调用重新激活用户 ID 的接口，传入已激活的用户 ID 时，返回该错误码。 |
| 24356 | 用户注销中 | 调用注销接口，传入正在注销流程中的用户 ID 时，返回该错误码。 |
|  24410 | 超级群不存在     | 未找到超级群，请先进行创建    |
|  24412 | 用户加入超级群数量超限     | 用户加入超级群数量超限，每个用户最多可加入 100 个超级群。    |
|  24413 | 频道数超出上限     | 该超级群下创建的频道数超限，每个超级群下默认可创建 50 个频道。    |
|  24414 | 超级群频道 ID 不存在      | 请确认该超级群下存在该频道。    |
|  24416 | 发送者不在超级群私有频道成员列表中      | 请确认该超级群下该私有频道的成员列表中是否包含该用户 ID，或者发送消息的频道 ID 是否填写正确。    |
|  24418 | 用户组数量超出限制      | 请检查该超级群下用户组数量。默认最多 50 个。    |
|  24419 | 重复的用户组 ID      | 请检查入参中的用户组 ID 是否重复。    |
|  24420 | 用户组不存在      | 请确认该超级群下是否存在该用户组，入参中的超级群 ID、用户组 ID 等是否填写正确。    |
|  24421 | 用户组成员数量超出限制      | 请检查该超级群用户组中的成员数量。默认最多 100 个用户。    |
|  24422 | 频道绑定的用户组数量超出限制      | 请检查该超级群频道绑定的用户组数量。默认单个频道最多支持与 10 个用户组绑定。    |
